yakumo.nova.v2.availability_zone

Package yakumo :: Package nova :: Package v2 :: Module availability_zone |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.nova.v2.availability_zone

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for availability zones in Compute API v2
    18  """
    19
    20  from yakumo import base
    21  from yakumo import mapper
    22  from yakumo import exception
    23
    24
    25  ATTRIBUTE_MAPPING = [
    26      ('name', 'zoneName', mapper.Noop),
    27      ('status', 'zoneState', mapper.Noop),
    28      ('hosts', 'hosts', mapper.Noop),
    29  ]
    30
    31
    32 -class Resource(base.Resource):
    33      """Resource class for availability zones in Compute API v2"""
    34
    35
    36 -class Manager(base.Manager):
    37      """Manager class for availability zones in Compute API v2"""
    38
    39      resource_class = Resource
    40      service_type = 'compute'
    41      _attr_mapping = ATTRIBUTE_MAPPING
    42      _hidden_methods = ["create", "update"]
    43      _id_attr = 'name'
    44      _json_resource_key = 'availabilityZoneInfo'
    45      _json_resources_key = 'availabilityZoneInfo'
    46      _url_resource_path = '/os-availability-zone'
    47      _url_resource_list_path = '/os-availability-zone/detail'
    48
    49 -    def get(self, name):
    50          try:
    51              return self.find_one(name=name)
    52          except exception.Forbidden:
    53              return self.get_empty(name)
    54